@@ -223,12 +223,14 @@ class PipelineRun(Document):
 class Group(Document):
     """Group data"""
     name = StringField(max_length=120, primary_key=True, required=True)
+    username = StringField(max_length=120, required=True)
     children = ListField(StringField(max_length=120))
 
 
 class Set(Document):
     """Set data"""
     name = StringField(max_length=120, primary_key=True, required=True)
+    username = StringField(max_length=120, required=True)
     children = ListField(StringField(max_length=120))
 
 
@@ -280,9 +282,41 @@ class UserContribution(Document):
     file = StringField()
     line_history = EmbeddedDocumentListField(LineHistory)
 
+
 class FileCommitHistory(Document):
     """File line commit history"""
     organization = StringField()
     repository = StringField()
     file = StringField()
     commits = ListField(StringField())
+
+
+class Endpoints(Document):
+    """ URLs that need to be tested 
+    
+    Attributes:
+        name (StringField): Endpoint name
+        url (StringField): Endpoint URL address which will be tested
+        num_requests (IntField): Number of requests.
+        response_timeout (IntField): Stop waiting for a response after a given number of seconds
+    """
+    name = StringField(max_length=120, required=True)
+    url = StringField(required=True)
+    num_requests = IntField()
+    response_timeout = IntField()
+
+class SmokeTestResults(Document):
+    """ Smoke test results """
+    name = StringField(max_length=120, required=True)
+    url = StringField(required=True)
+    response_status = StringField(required=True)
+    avg_response_time = FloatField()
+
+class CrawlerHistory(Document):
+    """ Crawler History  """
+    sysetm = StringField(max_length=120, required=True)
+    timestamp = DateTimeField(required=True)
+    url = StringField(required=True)
+    run_time = FloatField()
+    number_of_events = IntField()
+    logs = StringField(max_length=10000)
\ No newline at end of file
